DAQInfiniteQueryResponse<T> class

Constructors

DAQInfiniteQueryResponse({required List<T> items, required int currentPage, required int totalPages, required int totalItems, required bool hasNextPage})

Properties

currentPage → int
final
hashCode → int
The hash code for this object.
no setteroverride
hasNextPage → bool
final
items → List<T>
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
totalItems → int
final
totalPages → int
final

Methods

copyWith({List<T>? items, int? currentPage, int? totalPages, int? totalItems, bool? hasNextPage}) → DAQInfiniteQueryResponse<T>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(covariant DAQInfiniteQueryResponse<T> other) → bool
The equality operator.
override