InfiniteQueryState<TData, TParams, TError> class

Constructors

InfiniteQueryState({List<TData> data = const [], required TParams parameters, int currentPage = 1, int totalPages = 0, int totalItems = 0, bool hasNextPage = false, InfiniteQueryLoadingState loadingState = InfiniteQueryLoadingState.initial, TError? error})

Properties

currentPage → int
final
data → List<TData>
final
error → TError?
final
hasError → bool
no setter
hashCode → int
The hash code for this object.
no setteroverride
hasNextPage → bool
final
isEmpty → bool
no setter
isLoading → bool
no setter
isLoadingMore → bool
no setter
isNotEmpty → bool
no setter
isSuccess → bool
no setter
itemCount → int
no setter
loadingState → InfiniteQueryLoadingState
final
parameters → TParams
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
totalItems → int
final
totalPages → int
final

Methods

copyWith({List<TData>? data, TParams? parameters, int? currentPage, int? totalPages, int? totalItems, bool? hasNextPage, InfiniteQueryLoadingState? loadingState, TError? error}) → InfiniteQueryState<TData, TParams, TError>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(covariant InfiniteQueryState<TData, TParams, TError> other) → bool
The equality operator.
override