MutationLoadingState enum

Enum representing the status of a mutation

Inheritance
Available extensions

Values

idle → const MutationLoadingState
loading → const MutationLoadingState
success → const MutationLoadingState
error → const MutationLoadingState

Properties

hashCode → int
The hash code for this object.
no setterinherited
index → int
A numeric identifier for the enumerated value.
no setterinherited
isError → bool

Available on MutationLoadingState, provided by the MutationStatusX extension

no setter
isIdle → bool

Available on MutationLoadingState, provided by the MutationStatusX extension

no setter
isLoading → bool

Available on MutationLoadingState, provided by the MutationStatusX extension

no setter
isSuccess → bool

Available on MutationLoadingState, provided by the MutationStatusX extension

no setter
name → String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

values → const List<MutationLoadingState>
A constant List of the values in this enum, in order of their declaration.