CacheTTLConfig class

Constructors

CacheTTLConfig({Duration? defaultInfiniteQueryTTL, Duration? defaultQueryTTL, bool? enablePeriodicTTLRefresh})

Properties

defaultInfiniteQueryTTL ↔ Duration?
getter/setter pair
defaultQueryTTL ↔ Duration?
Global cache entry ttl for all useQuery instances.
getter/setter pair
enablePeriodicTTLRefresh ↔ bool
IF all reactive refreshing on TTL exploration should be disabled. By default it is enabled - meaning there is an internal timer on each useQuery, useInfiniteQuery that would perform a refetch each x interval (if it was actually set globally in this config, or for the particular query.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited